---
name: Bug Report
about: Use this template to report an issue.
title: ''
labels: bug
assignees: FabienLavocat
---

**Describe the bug**

[A clear and concise description of what the bug is.]

**Expected Behavior**

[Describe the expected behavior of the feature.]

**Minimalistic code (recommended)**

[Please provide a link to a repository showing specifically the issue. It should only have the minimal footprint of your own implementation - something which does not requires any NDA.]

**Specifications**

-   OS: [e.g. Windows, Linux, macOS, ...]
-   Version:
    -   _for each libraries : name -> version_
    -   [e.g. dolbyio-rest-apis-client 1.8.7]
    -   [e.g. python 3.10]
    -   [...]
